@@ -1,8 +1,8 @@
 #!/bin/sh
 #Info.sh
-#version 2.0.0
-#by incrys for www.maemomeego.net
+#version 2.0.1-9.8
+#by incrys for www.smartphonetab.net
 
 zenity --info --title="About" --text="From an idea by Incrys, small application for cleaning and restoration applications. 
 Thanks to Veleno and m750 for their help with the QT GUI. 
-More information on MaemoMeego.net"
+More information on SmartPhoneTab.net"
